@@ -1,13 +1,20 @@
 # -*- coding: utf-8 -*-
-"""command line tool
+"""Command Line Tool
+=======================
+
+.. important::
+
+   This module requires ``emoji`` package to be installed.
 
 :mod:`pcapkit.__main__` was originally the module file of
 |jspcapy|_, which is now deprecated and merged with :mod:`pcapkit`.
 
+.. |jspcapy| replace:: ``jspcapy``
+.. _jspcapy: https://github.com/JarryShaw/jspcapy
+
 """
 import argparse
 import sys
-import warnings
 from typing import TYPE_CHECKING
 
 from pcapkit.utilities.compat import ModuleNotFoundError  # pylint: disable=redefined-builtin
@@ -27,7 +34,7 @@ if TYPE_CHECKING:
     from argparse import ArgumentParser
 
 #: version number
-__version__ = '0.16.1'
+__version__ = '0.16.3'
 
 
 def get_parser() -> 'ArgumentParser':
@@ -60,7 +67,7 @@ def get_parser() -> 'ArgumentParser':
                               'tools. This option overrides all other options.'))
     parser.add_argument('-a', '--auto-extension', action='store_true', default=False,
                         help='If output file extension omits, append automatically.')
-    parser.add_argument('-v', '--verbose', action='store_false', default=True,
+    parser.add_argument('-v', '--verbose', action='store_true', default=False,
                         help='Show more information.')
     parser.add_argument('-F', '--files', action='store_true', default=False,
                         help='Split each frame into different files.')
@@ -79,7 +86,6 @@ def main() -> 'int':
     """Entrypoint."""
     parser = get_parser()
     args = parser.parse_args()
-    warnings.simplefilter('ignore')
 
     if args.format:
         fmt = args.format
@@ -92,19 +98,22 @@ def main() -> 'int':
     else:
         fmt = None
 
-    extractor = Extractor(store=False, format=fmt,
+    extractor = Extractor(store=False, auto=False,
                           fin=args.fin, fout=args.fout,
-                          auto=args.verbose, files=args.files,
+                          files=args.files, format=fmt,
                           layer=args.layer, protocol=args.protocol,
                           engine=args.engine, extension=args.auto_extension,
                           verbose=args.verbose)
 
-    if not args.verbose:
+    if args.verbose:
         try:
             print(emoji.emojize(f":police_car_light: Loading file {extractor.input!r}"))
         except UnicodeEncodeError:
             print(f"[*] Loading file {extractor.input!r}")
 
+        for _ in extractor:
+            pass
+
         try:
             print(emoji.emojize(f":beer_mug: Report file{'s' if args.files else ''} stored in {extractor.output!r}"))
         except UnicodeEncodeError:
