@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=unused-import
-"""core utilities
+"""Core Utilities
+====================
 
 :mod:`pcapkit.corekit` is the collection of core utilities
 for :mod:`pcapkit` implementation, including :obj:`dict` like
 class :class:`~pcapkit.corekit.infoclass.Info`,
 :obj:`tuple` like class :class:`~pcapkit.corekit.version.VersionInfo`,
-and protocol collection class :class:`~pcapkit.corekit.protochain.ProtoChain`.
+protocol collection class :class:`~pcapkit.corekit.protochain.ProtoChain`,
+and :class:`~pcapkit.corekit.multidict.MultiDict` family inspired from
+:mod:`Werkzeug` for multientry :obj:`dict` data mapping.
 
 """
 from pcapkit.corekit.infoclass import Info
