@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""protocol chain collection
+"""Protocol Chain
+====================
 
 :mod:`pcapkit.corekit.protochain` contains special protocol
 collection class :class:`~pcapkit.corekit.protochain.ProtoChain`.
@@ -135,8 +136,6 @@ class ProtoChain(collections.abc.Sequence):
         Args:
             proto: New protocol class on the top stack.
             alias: New protocol alias on the top stack.
-
-        Keyword Args:
             basis: Original protocol chain as base stacks.
 
         """
