@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=import-outside-toplevel,fixme
-"""extractor for PCAP files
+"""Extractor for PCAP Files
+==============================
 
 :mod:`pcapkit.foundation.extraction` contains
 :class:`~pcapkit.foundation.extraction.Extractor` only,
@@ -74,16 +75,9 @@ class ReassemblyData(Info):
 class Extractor:
     """Extractor for PCAP files.
 
-    For supported engines, please refer to corresponding driver method for more information:
-
-    * Default drivers:
-
-      * Global header: :meth:`~pcapkit.foundation.extraction.Extractor.record_header`
-      * Packet frames: :meth:`~pcapkit.foundation.extraction.Extractor.record_frames`
-
-    * DPKT driver: :meth:`~pcapkit.foundation.extraction.Extractor._run_dpkt`
-    * Scapy driver: :meth:`~pcapkit.foundation.extraction.Extractor._run_scapy`
-    * PyShark driver: :meth:`~pcapkit.foundation.extraction.Extractor._run_pyshark`
+    Notes:
+        For supported engines, please refer to
+        :meth:`~pcapkit.foundation.extraction.Extractor.run`.
 
     """
     #: Input file name.
@@ -287,18 +281,18 @@ class Extractor:
 
     @classmethod
     def register(cls, format: 'str', module: 'str', class_: 'str', ext: 'str') -> 'None':  # pylint: disable=redefined-builtin
-        """Register a new dumper class.
-
-        Arguments:
-            format: format name
-            module: module name
-            class_: class name
-            ext: file extension
+        r"""Register a new dumper class.
 
         Notes:
             The full qualified class name of the new dumper class
             should be as ``{module}.{class_}``.
 
+        Arguments:
+            format: format name
+            module: module name
+            class\_: class name
+            ext: file extension
+
         """
         cls.__output__[format] = (module, class_, ext)
 
@@ -349,8 +343,6 @@ class Extractor:
 
         Args:
             engine: Extraction engine module name.
-
-        Keyword Args:
             name: Extraction engine display name.
 
         Warns:
@@ -396,8 +388,6 @@ class Extractor:
             extension: If append ``.pcap`` file extension to the input filename
                 if ``fin`` does not have such file extension; if check and append extensions
                 to output file.
-
-        Keyword Args:
             files: If split each frame into different files.
             nofile: If no output file is to be dumped.
 
@@ -430,7 +420,17 @@ class Extractor:
             ext = cls.__output__[fmt][2]
             if ext is None:
                 raise FormatError(f'unknown output format: {fmt}')
-            os.makedirs(os.path.split(fout)[0], exist_ok=True)
+
+            if False:
+                parent = NotImplemented
+
+            def _walrus_wrapper_parent_eac7e34be7e1442485e1fa2c7c36c70e(expr):
+                """Wrapper function for assignment expression."""
+                nonlocal parent
+                parent = expr
+                return parent
+            if (_walrus_wrapper_parent_eac7e34be7e1442485e1fa2c7c36c70e(os.path.split(fout)[0])):
+                os.makedirs(parent, exist_ok=True)
 
             if files:
                 ofnm = fout
@@ -512,7 +512,7 @@ class Extractor:
                  trace_byteorder: 'Literal["big", "little"]' = sys.byteorder, trace_nanosecond: 'bool' = False) -> 'None':      # trace settings # pylint: disable=line-too-long
         """Initialise PCAP Reader.
 
-        Arguments:
+        Args:
             fin: file name to be read; if file not exist, raise :exc:`FileNotFound`
             fout: file name to be written
             format: file format of output
@@ -523,7 +523,7 @@ class Extractor:
 
             files: if split each frame into different files
             nofile: if no output file is to be dumped
-            verbose: a :obj:`bool` value or a function takes the :class:`Extract`
+            verbose: a :obj:`bool` value or a function takes the :class:`Extractor`
                 instance and current parsed frame (depends on engine selected) as
                 parameters to print verbose output information
 
@@ -660,7 +660,7 @@ class Extractor:
                         )
                     return super().object_hook(o)  # type: ignore[unreachable]
 
-                def default(self, o: 'Any') -> 'Literal["fallback"]':  # pylint: disable=no-self-use,unused-argument
+                def default(self, o: 'Any') -> 'Literal["fallback"]':  # pylint: disable=unused-argument
                     """Check content type for function call."""
                     return 'fallback'
 
