@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""registry management
+"""Registry Management
+=========================
 
 This module provides the registry management for :mod:`pcapkit`, as the module
 contains various registry points.
@@ -13,7 +14,7 @@ from dictdumper import Dumper
 from pcapkit.foundation.extraction import Extractor
 from pcapkit.foundation.traceflow import TraceFlow
 from pcapkit.protocols import __proto__ as protocol_registry
-from pcapkit.protocols.application.httpv2 import HTTPv2
+from pcapkit.protocols.application.httpv2 import HTTP as HTTPv2
 from pcapkit.protocols.internet.hopopt import HOPOPT
 from pcapkit.protocols.internet.internet import Internet
 from pcapkit.protocols.internet.ipv6_opts import IPv6_Opts
@@ -27,8 +28,9 @@ from pcapkit.utilities.exceptions import RegistryError
 from pcapkit.utilities.logging import logger
 
 if TYPE_CHECKING:
-    from typing import Type
+    from typing import Callable, Type
 
+    from mypy_extensions import NamedArg
     from typing_extensions import Literal
 
     from pcapkit.const.http.frame import Frame as HTTP_Frame
@@ -39,12 +41,35 @@ if TYPE_CHECKING:
     from pcapkit.const.reg.transtype import TransType
     from pcapkit.const.tcp.mp_tcp_option import MPTCPOption as TCP_MPTCPOption
     from pcapkit.const.tcp.option import Option as TCP_Option
-    from pcapkit.protocols.application.httpv2 import FrameParser as HTTP_FrameParser
-    from pcapkit.protocols.internet.hopopt import OptionParser as HOPOPT_OptionParser
-    from pcapkit.protocols.internet.ipv6_opts import OptionParser as IPv6_Opts_OptionParser
-    from pcapkit.protocols.internet.ipv6_route import TypeParser as IPv6_Route_TypeParser
-    from pcapkit.protocols.transport.tcp import MPOptionParser as TCP_MPOptionParser
-    from pcapkit.protocols.transport.tcp import OptionParser as TCP_OptionParser
+    from pcapkit.corekit.multidict import OrderedMultiDict
+    from pcapkit.protocols.data.application.httpv2 import HTTP as DataType_HTTPv2
+    from pcapkit.protocols.data.internet.hopopt import Option as DataType_HOPOPT_Option
+    from pcapkit.protocols.data.internet.ipv6_opts import Option as DataType_IPv6_Opts_Option
+    from pcapkit.protocols.data.internet.ipv6_route import \
+        RoutingType as DataType_IPv6_Route_RoutingType
+    from pcapkit.protocols.data.transport.tcp import MPTCP as DataType_TCP_MPTCP
+    from pcapkit.protocols.data.transport.tcp import Option as DataType_TCP_Option
+
+    #from pcapkit.protocols.application.httpv2 import FrameParser as HTTP_FrameParser
+    HTTP_FrameParser = Callable[[HTTPv2, HTTP_Frame, int, str, int], DataType_HTTPv2]
+    #from pcapkit.protocols.internet.hopopt import OptionParser as HOPOPT_OptionParser
+    HOPOPT_OptionParser = Callable[[HOPOPT, IPv6_Option, int, bool,
+                                    NamedArg(OrderedMultiDict[IPv6_Option, DataType_HOPOPT_Option], 'options')],
+                                   DataType_HOPOPT_Option]
+    #from pcapkit.protocols.internet.ipv6_opts import OptionParser as IPv6_Opts_OptionParser
+    IPv6_Opts_OptionParser = Callable[[IPv6_Opts, IPv6_Option, int, bool,
+                                       NamedArg(OrderedMultiDict[IPv6_Option, DataType_IPv6_Opts_Option], 'options')],
+                                      DataType_IPv6_Opts_Option]
+    #from pcapkit.protocols.internet.ipv6_route import TypeParser as IPv6_Route_TypeParser
+    IPv6_Route_TypeParser = Callable[[IPv6_Route, int], DataType_IPv6_Route_RoutingType]
+    #from pcapkit.protocols.transport.tcp import MPOptionParser as TCP_MPOptionParser
+    TCP_MPOptionParser = Callable[[TCP, TCP_MPTCPOption, int, str,
+                                   NamedArg(OrderedMultiDict[TCP_Option, DataType_TCP_Option], 'options')],
+                                  DataType_TCP_MPTCP]
+    #from pcapkit.protocols.transport.tcp import OptionParser as TCP_OptionParser
+    TCP_OptionParser = Callable[[TCP, TCP_Option,
+                                 NamedArg(OrderedMultiDict[TCP_Option, DataType_TCP_Option], 'options')],
+                                DataType_TCP_Option]
 
 __all__ = [
     'register_protocol',
@@ -61,20 +86,20 @@ __all__ = [
 ]
 
 ###############################################################################
-# pcapkit.protocols.__proto__
+# pcapkit.protocols.Protocol.__proto__
 ###############################################################################
 
 
 def register_protocol(protocol: 'Type[Protocol]') -> 'None':
     """registered protocol class.
 
-    Args:
-        protocol: Protocol class.
-
     The protocol class must be a subclass of
     :class:`~pcapkit.protocols.protocol.Protocol`, and will be registered to
     the :data:`pcapkit.protocols.__proto__` registry.
 
+    Args:
+        protocol: Protocol class.
+
     """
     if not issubclass(protocol, Protocol):
         raise RegistryError('protocol must be a Protocol subclass')
@@ -89,13 +114,7 @@ def register_protocol(protocol: 'Type[Protocol]') -> 'None':
 
 
 def register_extractor(format: 'str', module: 'str', class_: 'str', ext: 'str') -> 'None':  # pylint: disable=redefined-builtin
-    """registered a new dumper class.
-
-    Arguments:
-        format: format name
-        module: module name
-        class_: class name
-        ext: file extension
+    r"""registered a new dumper class.
 
     Notes:
         The full qualified class name of the new dumper class
@@ -104,6 +123,12 @@ def register_extractor(format: 'str', module: 'str', class_: 'str', ext: 'str')
     The function will register the given dumper class to the
     :data:`pcapkit.foundation.extraction.Extractor.__output__` registry.
 
+    Arguments:
+        format: format name
+        module: module name
+        class\_: class name
+        ext: file extension
+
     """
     dumper = getattr(importlib.import_module(module), class_)
     if not issubclass(dumper, Dumper):
@@ -119,13 +144,7 @@ def register_extractor(format: 'str', module: 'str', class_: 'str', ext: 'str')
 
 
 def register_traceflow(format: 'str', module: 'str', class_: 'str', ext: 'str') -> 'None':  # pylint: disable=redefined-builtin
-    """registered a new dumper class.
-
-    Arguments:
-        format: format name
-        module: module name
-        class_: class name
-        ext: file extension
+    r"""registered a new dumper class.
 
     Notes:
         The full qualified class name of the new dumper class
@@ -134,6 +153,12 @@ def register_traceflow(format: 'str', module: 'str', class_: 'str', ext: 'str')
     The function will register the given dumper class to the
     :data:`pcapkit.foundation.traceflow.TraceFlow.__output__` registry.
 
+    Arguments:
+        format: format name
+        module: module name
+        class\_: class name
+        ext: file extension
+
     """
     dumper = getattr(importlib.import_module(module), class_)
     if not issubclass(dumper, Dumper):
@@ -151,13 +176,14 @@ def register_traceflow(format: 'str', module: 'str', class_: 'str', ext: 'str')
 def register_http(code: 'HTTP_Frame', meth: 'str | HTTP_FrameParser') -> 'None':
     """registered a frame parser.
 
-    Args:
-        code: HTTP frame type code.
-        meth: Method name or callable to parse the frame.
-
     The function will register the given frame parser to the
     :data:`pcapkit.protocols.application.httpv2.HTTPv2.__frame__` registry.
 
+    Args:
+        code: :class:`HTTP/2 <pcapkit.protocols.application.httpv2.HTTPv2>` frame type
+            code as in :class:`~pcapkit.const.http.frame.Frame`.
+        meth: Method name or callable to parse the frame.
+
     """
     if isinstance(meth, str) and not hasattr(HTTPv2, f'_read_http_{meth}'):
         raise RegistryError('method must be a frame parser function')
@@ -174,13 +200,14 @@ def register_http(code: 'HTTP_Frame', meth: 'str | HTTP_FrameParser') -> 'None':
 def register_hopopt(code: 'IPv6_Option', meth: 'str | HOPOPT_OptionParser') -> 'None':
     """Register an option parser.
 
-    Args:
-        code: HOPOPT option code.
-        meth: Method name or callable to parse the option.
-
     The function will register the given option parser to the
     :data:`pcapkit.protocols.internet.hopopt.HOPOPT.__option__` registry.
 
+    Args:
+        code: :class:`~pcapkit.protocols.internet.hopopt.HOPOPT` option code as
+            in :class:`~pcapkit.const.ipv6.option.Option`.
+        meth: Method name or callable to parse the option.
+
     """
     if isinstance(meth, str) and not hasattr(HOPOPT, f'_read_opt_{meth}'):
         raise RegistryError('method must be a HOPOPT option parser function')
@@ -195,12 +222,7 @@ def register_hopopt(code: 'IPv6_Option', meth: 'str | HOPOPT_OptionParser') -> '
 
 
 def register_transtype(code: 'TransType', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: protocol code as in :class:`~pcapkit.const.reg.transtype.TransType`
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -209,6 +231,11 @@ def register_transtype(code: 'TransType', module: str, class_: str) -> 'None':
     The function will register the given protocol class to the
     :data:`pcapkit.protocols.internet.internet.Internet.__proto__` registry.
 
+    Arguments:
+        code: protocol code as in :class:`~pcapkit.const.reg.transtype.TransType`
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -229,13 +256,14 @@ def register_transtype(code: 'TransType', module: str, class_: str) -> 'None':
 def register_ipv6_opts(code: 'IPv6_Option', meth: 'str | IPv6_Opts_OptionParser') -> 'None':
     """Register an option parser.
 
-    Args:
-        code: IPv6-Opts option code.
-        meth: Method name or callable to parse the option.
-
     The function will register the given option parser to the
     :data:`pcapkit.protocols.internet.ipv6_opts.IPv6_Opts.__option__` registry.
 
+    Args:
+        code: :class:`IPv6-Opts <pcapkit.protocols.internet.ipv6_opts.IPv6_Opts>`
+            option code as in :class:`~pcapkit.const.ipv6.option.Option`.
+        meth: Method name or callable to parse the option.
+
     """
     if isinstance(meth, str) and not hasattr(IPv6_Opts, f'_read_opt_{meth}'):
         raise RegistryError('method must be a IPv6_Opts option parser function')
@@ -250,15 +278,16 @@ def register_ipv6_opts(code: 'IPv6_Option', meth: 'str | IPv6_Opts_OptionParser'
 
 
 def register_ipv6_route(code: 'IPv6_Routing', meth: 'str | IPv6_Route_TypeParser') -> 'None':
-    """Register an routing data parser.
-
-    Args:
-        code: IPv6-Route data type code.
-        meth: Method name or callable to parse the data.
+    r"""Register an routing data parser.
 
     The function will register the given routing data parser to the
     :data:`pcapkit.protocols.internet.ipv6_route.IPv6_Route.__routing__` registry.
 
+    Args:
+        code: :class:`IPv6-Route <pcapkit.protocols.internet.ipv6_route.IPv6_Route>`
+            data type code as in :class:`~pcapkit.const.ipv6.routing.Routing`.
+        meth: Method name or callable to parse the data.
+
     """
     if isinstance(meth, str) and not hasattr(IPv6_Route, f'_read_data_type_{meth}'):
         raise RegistryError('method must be a IPv6_Route routing data parser function')
@@ -273,12 +302,7 @@ def register_ipv6_route(code: 'IPv6_Routing', meth: 'str | IPv6_Route_TypeParser
 
 
 def register_ethertype(code: 'EtherType', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: protocol code as in :class:`~pcapkit.const.reg.ethertype.EtherType`
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -287,6 +311,11 @@ def register_ethertype(code: 'EtherType', module: str, class_: str) -> 'None':
     The function will register the given protocol class to the
     :data:`pcapkit.protocols.link.link.Link.__proto__` registry.
 
+    Arguments:
+        code: protocol code as in :class:`~pcapkit.const.reg.ethertype.EtherType`
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -305,12 +334,7 @@ def register_ethertype(code: 'EtherType', module: str, class_: str) -> 'None':
 
 
 def register_pcap(code: 'LinkType', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: protocol code as in :class:`~pcapkit.const.reg.linktype.LinkType`
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -319,6 +343,11 @@ def register_pcap(code: 'LinkType', module: str, class_: str) -> 'None':
     The function will register the given protocol class to the
     :data:`pcapkit.protocols.misc.pcap.frame.Frame.__proto__` registry.
 
+    Arguments:
+        code: protocol code as in :class:`~pcapkit.const.reg.linktype.LinkType`
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -339,13 +368,14 @@ def register_pcap(code: 'LinkType', module: str, class_: str) -> 'None':
 def register_tcp(code: 'TCP_Option', meth: 'str | TCP_OptionParser') -> 'None':
     """Register an option parser.
 
-    Args:
-        code: TCP option code.
-        meth: Method name or callable to parse the option.
-
     The function will register the given option parser to the
     :data:`pcapkit.protocols.transport.tcp.TCP.__option__` registry.
 
+    Args:
+        code: :class:`~pcapkit.protocols.transport.tcp.TCP` option code as in
+            :class:`~pcapkit.const.tcp.option.Option`.
+        meth: Method name or callable to parse the option.
+
     """
     if isinstance(meth, str) and not hasattr(TCP, f'_read_mode_{meth}'):
         raise RegistryError('method must be a TCP option parser function')
@@ -362,13 +392,14 @@ def register_tcp(code: 'TCP_Option', meth: 'str | TCP_OptionParser') -> 'None':
 def register_mptcp(code: 'TCP_MPTCPOption', meth: 'str | TCP_MPOptionParser') -> 'None':
     """Register an MPTCP option parser.
 
-    Args:
-        code: MPTCP option code.
-        meth: Method name or callable to parse the option.
-
     The function will register the given option parser to the
     :data:`pcapkit.protocols.transport.tcp.TCP.__mp_option__` registry.
 
+    Args:
+        code: Multipath :class:`~pcapkit.protocols.transport.tcp.TCP` option code as in
+            :class:`~pcapkit.const.tcp.mp_tcp_option.MPTCPOption`.
+        meth: Method name or callable to parse the option.
+
     """
     if isinstance(meth, str) and not hasattr(TCP, f'_read_mptcp_{meth}'):
         raise RegistryError('method must be a MPTCP option parser function')
@@ -383,12 +414,7 @@ def register_mptcp(code: 'TCP_MPTCPOption', meth: 'str | TCP_MPOptionParser') ->
 
 
 def register_tcp_port(code: 'int', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: port number
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -397,6 +423,11 @@ def register_tcp_port(code: 'int', module: str, class_: str) -> 'None':
     The function will register the given protocol class to the
     :data:`pcapkit.protocols.transport.tcp.TCP.__proto__` registry.
 
+    Arguments:
+        code: port number
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -410,17 +441,12 @@ def register_tcp_port(code: 'int', module: str, class_: str) -> 'None':
 
 
 ###############################################################################
-# pcapkit.protocols.transport.tcp.UDP.__proto__
+# pcapkit.protocols.transport.udp.UDP.__proto__
 ###############################################################################
 
 
 def register_udp_port(code: 'int', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: port number
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -429,6 +455,11 @@ def register_udp_port(code: 'int', module: str, class_: str) -> 'None':
     The function will register the given protocol class to the
     :data:`pcapkit.protocols.transport.udp.UDP.__proto__` registry.
 
+    Arguments:
+        code: port number
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -447,13 +478,7 @@ def register_udp_port(code: 'int', module: str, class_: str) -> 'None':
 
 
 def register_output(format: 'str', module: 'str', class_: 'str', ext: 'str') -> 'None':  # pylint: disable=redefined-builtin
-    """registered a new dumper class.
-
-    Arguments:
-        format: format name
-        module: module name
-        class_: class name
-        ext: file extension
+    r"""registered a new dumper class.
 
     Notes:
         The full qualified class name of the new dumper class
@@ -467,6 +492,12 @@ def register_output(format: 'str', module: 'str', class_: 'str', ext: 'str') ->
         * :func:`pcapkit.foundation.registry.register_extractor`
         * :func:`pcapkit.foundation.registry.register_traceflow`
 
+    Arguments:
+        format: format name
+        module: module name
+        class\_: class name
+        ext: file extension
+
     """
     dumper = getattr(importlib.import_module(module), class_)
     if not issubclass(dumper, Dumper):
@@ -478,12 +509,7 @@ def register_output(format: 'str', module: 'str', class_: 'str', ext: 'str') ->
 
 
 def register_linktype(code: 'LinkType', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        code: protocol code as in :class:`~pcapkit.const.reg.linktype.LinkType`
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -495,6 +521,11 @@ def register_linktype(code: 'LinkType', module: str, class_: str) -> 'None':
     See Also:
         * :func:`pcapkit.foundation.registry.register_pcap`
 
+    Arguments:
+        code: protocol code as in :class:`~pcapkit.const.reg.linktype.LinkType`
+        module: module name
+        class\_: class name
+
     """
     protocol = getattr(importlib.import_module(module), class_)
     if not issubclass(protocol, Protocol):
@@ -508,13 +539,7 @@ def register_linktype(code: 'LinkType', module: str, class_: str) -> 'None':
 
 
 def register_port(proto: 'Literal["tcp", "udp"]', code: 'int', module: str, class_: str) -> 'None':
-    """Register a new protocol class.
-
-    Arguments:
-        proto: protocol name (must be ``tcp`` or ``udp``)
-        code: port number
-        module: module name
-        class_: class name
+    r"""Register a new protocol class.
 
     Notes:
         The full qualified class name of the new protocol class
@@ -528,6 +553,12 @@ def register_port(proto: 'Literal["tcp", "udp"]', code: 'int', module: str, clas
         * :func:`pcapkit.foundation.registry.register_tcp_port`
         * :func:`pcapkit.foundation.registry.register_udp_port`
 
+    Arguments:
+        proto: protocol name (must be ``tcp`` or ``udp``)
+        code: port number
+        module: module name
+        class\_: class name
+
     """
     if proto == 'tcp':
         cls = TCP
