@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=unused-import,fixme
-"""application layer protocols
+"""Application Layer Protocols
+=================================
 
-`pcapkit.protocols.application` is collection of all
-protocols in application layer, with detailed
-implementation and methods.
+:mod:`pcapkit.protocols.application` is collection of all protocols in
+application layer, with detailed implementation and methods.
 
 """
 # TODO: Implements BGP, DHCP, DHCPv6, DNS, IMAP, LDAP, MQTT,
@@ -16,8 +16,8 @@ from pcapkit.protocols.application.application import Application
 
 # Utility Classes for Protocols
 from pcapkit.protocols.application.ftp import FTP
-from pcapkit.protocols.application.httpv1 import HTTPv1
-from pcapkit.protocols.application.httpv2 import HTTPv2
+from pcapkit.protocols.application.httpv1 import HTTP as HTTPv1
+from pcapkit.protocols.application.httpv2 import HTTP as HTTPv2
 
 # Deprecated / Base Classes
 from pcapkit.protocols.application.http import HTTP
