@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=unused-import,fixme
-"""internet layer protocols
+"""Internet Layer Protocols
+==============================
 
-`pcapkit.protocols.internet` is collection of all protocols
-in internet layer, with detailed implementation and
-methods.
+:mod:`pcapkit.protocols.internet` is collection of all protocols
+in internet layer, with detailed implementation and methods.
 
 """
 # TODO: Implements ECN, ESP, ICMP, ICMPv6, IGMP, Shim6.
