@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
-"""internet protocol security
+"""IPsec - Internet Protocol Security
+========================================
 
 :mod:`pcapkit.protocols.internet.ipsec` contains
 :class:`~pcapkit.protocols.internet.ipsec.IPsec`
 only, which is a base class for Internet Protocol
 Security (IPsec) protocol family [*]_, eg.
 :class:`~pcapkit.protocols.internet.ah.AH` and
-:class:`~pcapkit.protocols.internet.esp.ESP`
-(**NOT IMPLEMENTED**).
+:class:`~pcapkit.protocols.internet.esp.ESP` [*]_.
 
 .. [*] https://en.wikipedia.org/wiki/IPsec
+.. [*] :class:`~pcapkit.protocols.internet.esp.ESP`
+       class is currently **NOT** implemented.
 
 """
 from typing import TYPE_CHECKING, Generic
