@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""(inverse) address resolution protocol
+"""ARP/InARP - (Inverse) Address Resolution Protocol
+=======================================================
 
 :mod:`pcapkit.protocols.link.arp` contains
 :class:`~pcapkit.protocols.link.arp.ARP` only,
@@ -54,17 +55,27 @@ if TYPE_CHECKING:
 
 __all__ = ['ARP']
 
+if False:
+    version_info = NotImplemented
+
+
+def _walrus_wrapper_version_info_77d25785cc1543c3be068fe1179ceafd(expr):
+    """Wrapper function for assignment expression."""
+    global version_info
+    version_info = expr
+    return version_info
+
 # check Python version
-py38 = ((version_info := sys.version_info).major >= 3 and version_info.minor >= 8)
+py38 = ((_walrus_wrapper_version_info_77d25785cc1543c3be068fe1179ceafd(sys.version_info)).major >= 3 and version_info.minor >= 8)
 
 
 class ARP(Link[DataType_ARP]):
     """This class implements all protocols in ARP family.
 
-    - Address Resolution Protocol (ARP) [:rfc:`826`]
-    - Reverse Address Resolution Protocol (RARP) [:rfc:`903`]
-    - Dynamic Reverse Address Resolution Protocol (DRARP) [:rfc:`1931`]
-    - Inverse Address Resolution Protocol (InARP) [:rfc:`2390`]
+    - Address Resolution Protocol (:class:`~pcapkit.protocols.link.arp.ARP`) [:rfc:`826`]
+    - Reverse Address Resolution Protocol (:class:`~pcapkit.protocols.link.rarp.RARP`) [:rfc:`903`]
+    - Dynamic Reverse Address Resolution Protocol (:class:`~pcapkit.protocols.link.DRARP`) [:rfc:`1931`]
+    - Inverse Address Resolution Protocol (:class:`~pcapkit.protocols.link.InARP`) [:rfc:`2390`]
 
     """
     #: Name of corresponding protocol.
@@ -140,8 +151,6 @@ class ARP(Link[DataType_ARP]):
 
         Args:
             length: Length of packet data.
-
-        Keyword Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -194,7 +203,7 @@ class ARP(Link[DataType_ARP]):
     def make(self, **kwargs: 'Any') -> 'NoReturn':
         """Make (construct) packet data.
 
-        Keyword Args:
+        Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -252,9 +261,9 @@ class ARP(Link[DataType_ARP]):
     def _read_proto_resolve(self, length: 'int', ptype: 'int') -> 'str | IPv4Address | IPv6Address':
         """Resolve protocol address according to protocol.
 
-        Positional arguments:
-            length (int): Protocol address length.
-            ptype (int): Protocol type.
+        Arguments:
+            length: Protocol address length.
+            ptype: Protocol type.
 
         Returns:
             Protocol address. If ``ptype`` is ``0x0800``, i.e. IPv4 adddress,
