@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""ethernet protocol
+"""Ethernet Protocol
+=======================
 
 :mod:`pcapkit.protocols.link.ethernet` contains
 :class:`~pcapkit.protocols.link.ethernet.Ethernet`
@@ -24,6 +25,7 @@ import sys
 import textwrap
 from typing import TYPE_CHECKING
 
+from pcapkit.const.reg.linktype import LinkType as RegType_LinkType
 from pcapkit.protocols.data.link.ethernet import Ethernet as DataType_Ethernet
 from pcapkit.protocols.link.link import Link
 
@@ -36,8 +38,18 @@ if TYPE_CHECKING:
 
 __all__ = ['Ethernet']
 
+if False:
+    version_info = NotImplemented
+
+
+def _walrus_wrapper_version_info_eb614a92af9f4a3fa50ccb1353e2712a(expr):
+    """Wrapper function for assignment expression."""
+    global version_info
+    version_info = expr
+    return version_info
+
 # check Python version
-py38 = ((version_info := sys.version_info).major >= 3 and version_info.minor >= 8)
+py38 = ((_walrus_wrapper_version_info_eb614a92af9f4a3fa50ccb1353e2712a(sys.version_info)).major >= 3 and version_info.minor >= 8)
 
 
 class Ethernet(Link[DataType_Ethernet]):
@@ -98,13 +110,11 @@ class Ethernet(Link[DataType_Ethernet]):
            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
         Args:
-            length (Optional[int]): Length of packet data.
-
-        Keyword Args:
+            length: Length of packet data.
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
-            DataType_Ethernet: Parsed packet data.
+            Parsed packet data.
 
         """
         if length is None:
@@ -124,7 +134,7 @@ class Ethernet(Link[DataType_Ethernet]):
     def make(self, **kwargs: 'Any') -> 'NoReturn':
         """Make (construct) packet data.
 
-        Keyword Args:
+        Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -141,6 +151,19 @@ class Ethernet(Link[DataType_Ethernet]):
         """Return an estimated length for the object."""
         return 14
 
+    @classmethod
+    def __index__(cls) -> 'RegType_LinkType':  # pylint: disable=invalid-index-returned
+        """Numeral registry index of the protocol.
+
+        Returns:
+            Numeral registry index of the protocol in `tcpdump`_ link-layer
+            header types.
+
+        .. _tcpdump: https://www.tcpdump.org/linktypes.html
+
+        """
+        return RegType_LinkType.ETHERNET  # type: ignore[return-value]
+
     ##########################################################################
     # Utilities.
     ##########################################################################
