@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""root link layer protocol
+"""Base Protocol
+===================
 
 :mod:`pcapkit.protocols.link.link` contains :class:`~pcapkit.protocols.link.link.Link`,
 which is a base class for link layer protocols, e.g. :class:`~pcapkit.protocols.link.link.arp.ARP`/InARP,
@@ -12,11 +13,8 @@ from typing import TYPE_CHECKING, Generic
 
 from pcapkit.const.reg.ethertype import EtherType as RegType_EtherType
 from pcapkit.protocols.protocol import PT, Protocol
-from pcapkit.utilities.exceptions import UnsupportedCall
 
 if TYPE_CHECKING:
-    from typing import NoReturn
-
     from typing_extensions import Literal
 
 __all__ = ['Link']
@@ -26,7 +24,7 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
     """Abstract base class for link layer protocol family.
 
     This class currently supports parsing of the following protocols, which are
-    registered in the :attr:`self.__proto__ <pcapkit.protocols.link.Link.__proto__>`
+    registered in the :attr:`self.__proto__ <pcapkit.protocols.link.link.Link.__proto__>`
     attribute:
 
     .. list-table::
@@ -34,18 +32,18 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
 
        * - Index
          - Protocol
-       * - 0x0806
-         - :class:`~pcapkit.protocols.link.arp.ARP`
-       * - 0x8035
-         - :class:`~pcapkit.protocols.link.rarp.RARP`
-       * - 0x8100
-         - :class:`~pcapkit.protocols.link.vlan.VLAN`
-       * - 0x0800
-         - :class:`~pcapkit.protocols.internet.ipv4.IPv4`
-       * - 0x86DD
-         - :class:`~pcapkit.protocols.internet.ipv6.IPv6`
+       * - :attr:`~pcapkit.const.reg.ethertype.EtherType.Address_Resolution_Protocol`
+         - :class:`pcapkit.protocols.link.arp.ARP`
+       * - :attr:`~pcapkit.const.reg.ethertype.EtherType.Reverse_Address_Resolution_Protocol`
+         - :class:`pcapkit.protocols.link.rarp.RARP`
+       * - :attr:`~pcapkit.const.reg.ethertype.EtherType.Customer_VLAN_Tag_Type`
+         - :class:`pcapkit.protocols.link.vlan.VLAN`
+       * - :attr:`~pcapkit.const.reg.ethertype.EtherType.Internet_Protocol_version_4`
+         - :class:`pcapkit.protocols.internet.ipv4.IPv4`
+       * - :attr:`~pcapkit.const.reg.ethertype.EtherType.Internet_Protocol_version_6`
+         - :class:`pcapkit.protocols.internet.ipv6.IPv6`
        * - 0x8137
-         - :class:`~pcapkit.protocols.internet.ipx.IPX`
+         - :class:`pcapkit.protocols.internet.ipx.IPX`
 
     """
 
@@ -58,7 +56,7 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
 
     #: DefaultDict[int, tuple[str, str]]: Protocol index mapping for decoding next layer,
     #: c.f. :meth:`self._decode_next_layer <pcapkit.protocols.protocol.Protocol._decode_next_layer>`
-    #: & :meth:`self._import_next_layer <pcapkit.protocols.link.link.Link._import_next_layer>`.
+    #: & :meth:`self._import_next_layer <pcapkit.protocols.protocol.Protocol._import_next_layer>`.
     __proto__ = collections.defaultdict(
         lambda: ('pcapkit.protocols.misc.raw', 'Raw'),
         {
@@ -89,34 +87,20 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
 
     @classmethod
     def register(cls, code: 'RegType_EtherType', module: str, class_: str) -> 'None':
-        """Register a new protocol class.
-
-        Arguments:
-            code: protocol code as in :class:`~pcapkit.const.reg.ethertype.EtherType`
-            module: module name
-            class_: class name
+        r"""Register a new protocol class.
 
         Notes:
             The full qualified class name of the new protocol class
             should be as ``{module}.{class_}``.
 
+        Arguments:
+            code: protocol code as in :class:`~pcapkit.const.reg.ethertype.EtherType`
+            module: module name
+            class\_: class name
+
         """
         cls.__proto__[code] = (module, class_)
 
-    ##########################################################################
-    # Data models.
-    ##########################################################################
-
-    @classmethod
-    def __index__(cls) -> 'NoReturn':  # pylint: disable=invalid-index-returned
-        """Numeral registry index of the protocol.
-
-        Raises:
-            UnsupportedCall: This protocol has no registry entry.
-
-        """
-        raise UnsupportedCall(f'{cls.__name__!r} object cannot be interpreted as an integer')
-
     ##########################################################################
     # Utilities.
     ##########################################################################
@@ -125,7 +109,7 @@ class Link(Protocol[PT], Generic[PT]):  # pylint: disable=abstract-method
         """Read next layer protocol type.
 
         Arguments:
-            size buffer size
+            size: buffer size
 
         Returns:
             Internet layer protocol enumeration.
