@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""root protocol
+"""Root Protocol
+===================
 
 :mod:`pcapkit.protocols.protocol` contains
 :class:`~pcapkit.protocols.protocol.Protocol` only, which is
@@ -53,6 +54,10 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
     #: Parsed packet data.
     _info: 'PT'
+    #: Raw packet data.
+    _data: 'bytes'
+    #: Source packet stream.
+    _file: 'BinaryIO'
     #： Next layer protocol instance.
     _next: 'Protocol'
     #: Protocol chain instance.
@@ -175,8 +180,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
         Args:
             length: Length of packet data.
-
-        Keyword Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -188,7 +191,7 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
     def make(self, **kwargs: 'Any') -> 'bytes':
         """Make (construct) packet data.
 
-        Keyword Args:
+        Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -204,10 +207,11 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Should decoding failed using ``encoding``, the method will try again decoding
         the :obj:`bytes` as ``'unicode_escape'`` with ``'replace'`` for error handling.
 
+        See Also:
+            The method is a wrapping function for :meth:`bytes.decode`.
+
         Args:
             byte: Source bytestring.
-
-        Keyword Args:
             encoding: The encoding with which to decode the :obj:`bytes`.
                 If not provided, :mod:`pcapkit` will first try detecting its encoding
                 using |chardet|_. The fallback encoding would is **UTF-8**.
@@ -217,9 +221,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
                 as well as any other name registered with :func:`codecs.register_error` that
                 can handle :exc:`UnicodeDecodeError`.
 
-        See Also:
-            The method is a wrapping function for :meth:`bytes.decode`.
-
         .. |chardet| replace:: ``chardet``
         .. _chardet: https://chardet.readthedocs.io
 
@@ -238,10 +239,11 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Should decoding failed , the method will try again replacing ``'%'`` with ``'\\x'`` then
         decoding the ``url`` as ``'unicode_escape'`` with ``'replace'`` for error handling.
 
+        See Also:
+            This method is a wrapper function for :func:`urllib.parse.unquote`.
+
         Args:
             url: URL string.
-
-        Keyword Args:
             encoding: The encoding with which to decode the :obj:`bytes`.
             errors: The error handling scheme to use for the handling of decoding errors.
                 The default is ``'strict'`` meaning that decoding errors raise a
@@ -249,9 +251,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
                 as well as any other name registered with :func:`codecs.register_error` that
                 can handle :exc:`UnicodeDecodeError`.
 
-        See Also:
-            This method is a wrapper function for :func:`urllib.parse.unquote`.
-
         """
         try:
             return urllib.parse.unquote(url, encoding=encoding, errors=errors)
@@ -262,9 +261,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
     def expand_comp(value: 'str | Protocol | Type[Protocol]') -> 'tuple':
         """Expand protocol class to protocol name.
 
-        Args:
-            value: Protocol class or name.
-
         The method is used to expand protocol class to protocol name, in the
         following manner:
 
@@ -276,19 +272,29 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
            obtained from :meth:`Protocol.id <pcapkit.protocols.protocol.Protocol.id>`.
         3. If ``value`` is :obj:`str`, the method will attempt to search for
            the existing registered protocol class from
-           :obj:`pcapkit.protocols.__proto__` and follow **step 2**; otherwise,
+           :data:`pcapkit.protocols.__proto__` and follow **step 2**; otherwise,
            return the value itself.
 
+        Args:
+            value: Protocol class or name.
+
         """
         if isinstance(value, type) and issubclass(value, Protocol):
             comp = (value, *(name.upper() for name in value.id()))
         elif isinstance(value, Protocol):
             comp = (type(value), *(name.upper() for name in value.id()))
         else:
-            from pcapkit.protocols import \
-                __proto__ as protocols_registry  # pylint: disable=import-outside-toplevel
+            from pcapkit.protocols import __proto__ as protocols_registry  # pylint: disable=import-outside-toplevel # isort: skip
 
-            if (proto := protocols_registry.get(value.upper())) is not None:
+            if False:
+                proto = NotImplemented
+
+            def _walrus_wrapper_proto_f8c5d7a7bb0f49aa835ac040bfeb3ae2(expr):
+                """Wrapper function for assignment expression."""
+                nonlocal proto
+                proto = expr
+                return proto
+            if (_walrus_wrapper_proto_f8c5d7a7bb0f49aa835ac040bfeb3ae2(protocols_registry.get(value.upper()))) is not None:
                 comp = (proto, *(name.upper() for name in proto.id()))
             else:
                 comp = (value.upper(),)
@@ -301,8 +307,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Args:
             proto: Protocol registry number.
             payload: Packet payload.
-
-        Keyword Args:
             **kwargs: Arbitrary keyword arguments.
 
         Returns:
@@ -353,12 +357,10 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Args:
             file: Source packet stream.
             length: Length of packet data.
-
-        Keyword Args:
             _layer (str): Parse packet until ``_layer``
-                (:attr:`self._onerror <pcapkit.protocols.protocol.Protocol._exlayer>`).
+                (:attr:`self._exlayer <pcapkit.protocols.protocol.Protocol._exlayer>`).
             _protocol (str | Protocol | Type[Protocol]): Parse packet until ``_protocol``
-                (:attr:`self._onerror <pcapkit.protocols.protocol.Protocol._exproto>`).
+                (:attr:`self._exproto <pcapkit.protocols.protocol.Protocol._exproto>`).
             **kwargs: Arbitrary keyword arguments.
 
         """
@@ -388,8 +390,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Args:
             file: Source packet stream.
             length: Length of packet data.
-
-        Keyword Args:
             **kwargs: Arbitrary keyword arguments.
 
         See Also:
@@ -417,7 +417,17 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
             <Frame alias='...' frame=(..., packet=b'...', sethernet=..., protocols='Ethernet:IPv6:Raw')>
 
         """
-        if (cached := self.__cached__.get('__repr__')) is not None:
+
+        if False:
+            cached = NotImplemented
+
+        def _walrus_wrapper_cached_4596c47ee71d44ed897423a75404d853(expr):
+            """Wrapper function for assignment expression."""
+            nonlocal cached
+            cached = expr
+            return cached
+
+        if (_walrus_wrapper_cached_4596c47ee71d44ed897423a75404d853(self.__cached__.get('__repr__'))) is not None:
             return cached
 
         name = type(self).__name__
@@ -448,7 +458,17 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
             5e 60 d9 6b 97                                               ^`.k.
 
         """
-        if (cached := self.__cached__.get('__str__')) is not None:
+
+        if False:
+            cached = NotImplemented
+
+        def _walrus_wrapper_cached_2d82571979a34f8e881b5cfb9ae2b256(expr):
+            """Wrapper function for assignment expression."""
+            nonlocal cached
+            cached = expr
+            return cached
+
+        if (_walrus_wrapper_cached_2d82571979a34f8e881b5cfb9ae2b256(self.__cached__.get('__str__'))) is not None:
             return cached
 
         hexbuf = ' '.join(textwrap.wrap(self._data.hex(), 2))
@@ -472,7 +492,17 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
     def __len__(self) -> 'int':
         """Total length of corresponding protocol."""
-        if (cached := self.__cached__.get('__len__')) is not None:
+
+        if False:
+            cached = NotImplemented
+
+        def _walrus_wrapper_cached_fbca46d3aaba4cb78d3a816259c99e74(expr):
+            """Wrapper function for assignment expression."""
+            nonlocal cached
+            cached = expr
+            return cached
+
+        if (_walrus_wrapper_cached_fbca46d3aaba4cb78d3a816259c99e74(self.__cached__.get('__len__'))) is not None:
             return cached
 
         # cache and return
@@ -594,7 +624,7 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
     # Utilities.
     ##########################################################################
 
-    def _read_protos(self, size: int) -> 'Optional[StdlibEnum | AenumEnum]':  # pylint: disable=no-self-use, unused-argument
+    def _read_protos(self, size: int) -> 'Optional[StdlibEnum | AenumEnum]':  # pylint: disable=unused-argument
         """Read next layer protocol type.
 
         * If *succeed*, returns the enum of next layer protocol.
@@ -612,8 +642,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
         Args:
             *args: arbitrary positional arguments
-
-        Keyword Args:
             **kwargs: arbitrary keyword arguments
 
         Returns:
@@ -628,8 +656,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
         Arguments:
             size: buffer size
-
-        Keyword Arguments:
             signed: signed flag
             lilendian: little-endian flag
             quiet: quiet (no exception) flag
@@ -702,8 +728,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
         Arguments:
             length: length of the packet
-
-        Keyword Arguments:
             header: length of the packet header
             payload: length of the packet payload
             discard: flag if discard header data
@@ -733,8 +757,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
 
         Arguments:
             integer: integer to be packed
-
-        Keyword arguments:
             size: buffer size
             signed: signed flag
             lilendian: little-endian flag
@@ -819,8 +841,6 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         Arguments:
             name: item to be indexed
             default: default value
-
-        Keyword arguments:
             namespace: namespace for item
             reversed: if namespace is ``str -> int`` pairs
             pack: if need :func:`struct.pack` to pack the result
@@ -866,10 +886,10 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
         return index
 
     def _decode_next_layer(self, dict_: 'PT', proto: 'int', length: 'Optional[int]' = None) -> 'PT':
-        """Decode next layer protocol.
+        r"""Decode next layer protocol.
 
         Arguments:
-            dict_: info buffer
+            dict\_: info buffer
             proto: next layer protocol index
             length: valid (*non-padding*) length
 
@@ -913,12 +933,23 @@ class Protocol(Generic[PT], metaclass=abc.ABCMeta):
             module, name = self.__proto__[proto]
             protocol = cast('Type[Protocol]', getattr(importlib.import_module(module), name))
 
-        next_ = protocol(self._file, length, layer=self._exlayer, protocol=self._exproto)  # type: ignore[abstract]
+        next_ = protocol(self._file, length, alias=proto,
+                         layer=self._exlayer, protocol=self._exproto)  # type: ignore[abstract]
         return next_
 
     def _check_term_threshold(self) -> bool:
         """Check if reached termination threshold."""
-        if self._exlayer is None or (layer := self.__layer__) is None:
+
+        if False:
+            layer = NotImplemented
+
+        def _walrus_wrapper_layer_0653bad64515433787d4d8eb4e5bddd0(expr):
+            """Wrapper function for assignment expression."""
+            nonlocal layer
+            layer = expr
+            return layer
+
+        if self._exlayer is None or (_walrus_wrapper_layer_0653bad64515433787d4d8eb4e5bddd0(self.__layer__)) is None:
             layer_match = False
         else:
             layer_match = layer.upper() == self._exlayer.upper()
