@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=unused-wildcard-import
-"""utility functions and classes
+"""Utility Functions & Classes
+=================================
 
 :mod:`pcapkit.utilities` contains several useful functions
 and classes which are fundations of :mod:`pcapkit`, including
 decorater function :func:`~pcapkit.utilities.decorators.seekset`
 and :func:`~pcapkit.utilities.decorators.beholder`, and
-several user-refined exceptions and validations.
+several user-refined exceptions and warnings.
 
 """
 #from pcapkit.utilities.compat import *  # pylint: disable=redefined-builtin
