@@ -14,12 +14,10 @@ __all__ = [
 
     # classes
     'Collection', 'cached_property',
+    'Mapping', 'Tuple',
 
     # modules
     'pathlib',
-
-    # functions
-    'cached_property',
 ]
 
 version = sys.version_info[:2]
@@ -119,3 +117,10 @@ else:
                             )
                             raise TypeError(msg) from None
             return val
+
+if version < (3, 9):
+    from typing import Mapping, Tuple
+else:
+    from collections.abc import Mapping
+
+    Tuple = tuple  # type: ignore[assignment]
