@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
-"""user defined exceptions
+"""User Defined Exceptions
+=============================
 
 :mod:`pcapkit.exceptions` refined built-in exceptions.
 Make it possible to show only user error stack infomation [*]_,
 when exception raised on user's operation.
 
 .. [*] See |tbtrim|_ project for Pythonic implementation.
+
 .. |tbtrim| replace:: ``tbtrim``
 .. _tbtrim: https://github.com/gousaiyang/tbtrim
 
